"use strict";

// Wrap everything in an anonymous function to avoid polluting the global namespace
(function() {
  // Use the jQuery document ready signal to know when everything has been initialized
  $(document).ready(function() {
    // show busy cursor while init...
    //alert(document.body);
    //document.body.style.cursor = 'wait';
    //$("body").css("cursor", "progress");
    //alert("document ready event, model open " + isModelOpen);

    // Tell Tableau we'd like to initialize our extension
    tableau.extensions.initializeAsync().then(function() {
      // Once the extension is initialized, ask the user to choose a sheet
      //showChooseSheetDialog();

      showStatusBriefly("Tableau extension initialized.", 2000);

      // basically to do anything with this extension, the model needs to be open
      // e.g. - configure Variable Id
      // or   - loading user input control
      getUserId();

      //
      // Get the worksheet object we want to get the selected marks for
      // and add an event listener for changes to selected node
      /*const worksheet = getSelectedSheet("Map");

      // Add an event listener for the selection changed event on this sheet.
      unregisterEventHandlerFunction = worksheet.addEventListener(
        tableau.TableauEventType.MarkSelectionChanged,
        function(selectionEvent) {
			// show table with info on selected location
			alert("selectionEvent");
			showTable();
			return;
          // When the selection changes, reload the data
          loadSelectedMarks("Map");
        }
      );*/
    });
  });

  /**
   * Shows the choose sheet UI. Once a sheet is selected, the data table for the sheet is shown
   */

  function createButton(buttonTitle) {
    const button = $(`<button type='button' class='btn btn-default btn-block'>
      ${buttonTitle}
    </button>`);

    return button;
  }

  // This variable will save off the function we can call to unregister listening to marks-selected events
  let unregisterEventHandlerFunction;

  function loadSelectedMarks(worksheetName) {
    // Remove any existing event listeners
    //if (unregisterEventHandlerFunction) {
    //  unregisterEventHandlerFunction();
    //}

    // Get the worksheet object we want to get the selected marks for
    const worksheet = getSelectedSheet("Map");

    // Set our title to an appropriate value
    //$('#selected_marks_title').text(worksheet.name);

    // Call to get the selected marks for our sheet
    worksheet.getSelectedMarksAsync().then(function(marks) {
      // Get the first DataTable for our selected marks (usually there is just one)
      const worksheetData = marks.data[0];

      //alert(worksheetData.data[0][2].value);
      //selectedNodeId = worksheetData.data[0][2].value;
      //alert(selectedNodeId);

      updateVariableDefinition(
        "Selected_node_id",
        "'" + worksheetData.data[0][2].value + "'"
      );
    });
  }

  function populateDataTable(data, columns) {
    // Do some UI setup here to change the visible section and reinitialize the table
    $("#data_table_wrapper").empty();

    if (data.length > 0) {
      $("#no_data_message").css("display", "none");
      $("#data_table_wrapper").append(
        `<table id='data_table' class='table table-striped table-bordered'></table>`
      );

      // Do some math to compute the height we want the data table to be
      var top = $("#data_table_wrapper")[0].getBoundingClientRect().top;
      var height = $(document).height() - top - 130;

      // Initialize our data table with what we just gathered
      $("#data_table").DataTable({
        data: data,
        columns: columns,
        autoWidth: false,
        deferRender: true,
        scroller: true,
        scrollY: height,
        scrollX: true,
        dom: "<'row'<'col-sm-6'i><'col-sm-6'f>><'row'<'col-sm-12'tr>>" // Do some custom styling
      });
    } else {
      // If we didn't get any rows back, there must be no marks selected
      $("#no_data_message").css("display", "inline");
    }
  }

  function initializeButtons() {
    $("#show_choose_sheet_button").click(showChooseSheetDialog);
  }

  function getSelectedSheet(worksheetName) {
    // Go through all the worksheets in the dashboard and find the one we want
    return tableau.extensions.dashboardContent.dashboard.worksheets.find(
      function(sheet) {
        return sheet.name === worksheetName;
      }
    );
  }
})();
